==> process-usertasks-with-security-springboot-0.9.1-sources.jar: org/acme/travels/ApprovalsModelInput.java <==
package org.acme.travels;

import java.util.Map;
import java.util.HashMap;

@org.kie.internal.kogito.codegen.Generated(value = "kogit-codegen", reference = "approvals", name = "Approvals", hidden = true)
public class ApprovalsModelInput implements org.kie.kogito.Model {

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("approver", this.approver);
        params.put("firstLineApproval", this.firstLineApproval);
        params.put("secondLineApproval", this.secondLineApproval);
        params.put("traveller", this.traveller);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.approver = (java.lang.String) params.get("approver");
        this.firstLineApproval = (java.lang.Boolean) params.get("firstLineApproval");
        this.secondLineApproval = (java.lang.Boolean) params.get("secondLineApproval");
        this.traveller = (org.acme.travels.Traveller) params.get("traveller");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "approver")
    @javax.validation.Valid()
    private java.lang.String approver;

    public java.lang.String getApprover() {
        return approver;
    }

    public void setApprover(java.lang.String approver) {
        this.approver = approver;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "firstLineApproval")
    @javax.validation.Valid()
    private java.lang.Boolean firstLineApproval;

    public java.lang.Boolean getFirstLineApproval() {
        return firstLineApproval;
    }

    public void setFirstLineApproval(java.lang.Boolean firstLineApproval) {
        this.firstLineApproval = firstLineApproval;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "secondLineApproval")
    @javax.validation.Valid()
    private java.lang.Boolean secondLineApproval;

    public java.lang.Boolean getSecondLineApproval() {
        return secondLineApproval;
    }

    public void setSecondLineApproval(java.lang.Boolean secondLineApproval) {
        this.secondLineApproval = secondLineApproval;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "traveller")
    @javax.validation.Valid()
    private org.acme.travels.Traveller traveller;

    public org.acme.travels.Traveller getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.travels.Traveller traveller) {
        this.traveller = traveller;
    }
}

==> process-usertasks-with-security-springboot-0.15.0-sources.jar: org/acme/travels/ApprovalsModelInput.java <==
package org.acme.travels;

import java.util.Map;
import java.util.HashMap;

@org.kie.internal.kogito.codegen.Generated(value = "kogito-codegen", reference = "approvals", name = "Approvals", hidden = true)
public class ApprovalsModelInput implements org.kie.kogito.Model {

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("approver", this.approver);
        params.put("firstLineApproval", this.firstLineApproval);
        params.put("secondLineApproval", this.secondLineApproval);
        params.put("traveller", this.traveller);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.approver = (java.lang.String) params.get("approver");
        this.firstLineApproval = (java.lang.Boolean) params.get("firstLineApproval");
        this.secondLineApproval = (java.lang.Boolean) params.get("secondLineApproval");
        this.traveller = (org.acme.travels.Traveller) params.get("traveller");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "approver")
    @javax.validation.Valid()
    private java.lang.String approver;

    public java.lang.String getApprover() {
        return approver;
    }

    public void setApprover(java.lang.String approver) {
        this.approver = approver;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "firstLineApproval")
    @javax.validation.Valid()
    private java.lang.Boolean firstLineApproval;

    public java.lang.Boolean getFirstLineApproval() {
        return firstLineApproval;
    }

    public void setFirstLineApproval(java.lang.Boolean firstLineApproval) {
        this.firstLineApproval = firstLineApproval;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "secondLineApproval")
    @javax.validation.Valid()
    private java.lang.Boolean secondLineApproval;

    public java.lang.Boolean getSecondLineApproval() {
        return secondLineApproval;
    }

    public void setSecondLineApproval(java.lang.Boolean secondLineApproval) {
        this.secondLineApproval = secondLineApproval;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "traveller")
    @javax.validation.Valid()
    private org.acme.travels.Traveller traveller;

    public org.acme.travels.Traveller getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.travels.Traveller traveller) {
        this.traveller = traveller;
    }

    public ApprovalsModel toModel() {
        ApprovalsModel result = new ApprovalsModel();
        result.setApprover(getApprover());
        result.setFirstLineApproval(getFirstLineApproval());
        result.setSecondLineApproval(getSecondLineApproval());
        result.setTraveller(getTraveller());
        return result;
    }
}
